DProperty mixin
Properties
- bottomBarHeight → double
-
底部安全区域高度
no setter
- hashCode → int
-
The hash code for this object.
no setterinherited
- height → double
-
屏幕高度
no setter
- isAndroid → bool
-
是否Android平台
no setter
- isDebug → bool
-
是否是调试模式
no setter
- isIOS → bool
-
是否iOS平台
no setter
- isMacOS → bool
-
是否MacOS平台
no setter
- isMobile → bool
-
是否移动端 iOS/Android
no setter
- isPlatformDarkMode → bool
-
是否暗黑模式
no setter
- isProfile → bool
-
是否是性能模式
no setter
- isRelease → bool
-
是否是调试模式
no setter
- isWeb → bool
-
是否web
no setter
- isWindows → bool
-
是否Windows平台
no setter
- pixelRatio → double
-
像素密度
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- size → Size
-
屏幕大小
no setter
- statusBarHeight → double
-
顶部状态栏高度
no setter
- width → double
-
屏幕宽度
no setter
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited